# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/ecm/node.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/ecm/node.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x65olymp/ecm/node.proto\x12\neolymp.ecm\"\x8f\x01\n\x04Node\x12\x0c\n\x04type\x18\x01 \x01(\t\x12(\n\x04\x61ttr\x18\x02 \x03(\x0b\x32\x1a.eolymp.ecm.Node.AttrEntry\x12\"\n\x08\x63hildren\x18\x03 \x03(\x0b\x32\x10.eolymp.ecm.Node\x1a+\n\tAttrEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42)Z\'github.com/eolymp/go-sdk/eolymp/ecm;ecmb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ecm.node_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\'github.com/eolymp/go-sdk/eolymp/ecm;ecm'
  _globals['_NODE_ATTRENTRY']._loaded_options = None
  _globals['_NODE_ATTRENTRY']._serialized_options = b'8\001'
  _globals['_NODE']._serialized_start=38
  _globals['_NODE']._serialized_end=181
  _globals['_NODE_ATTRENTRY']._serialized_start=138
  _globals['_NODE_ATTRENTRY']._serialized_end=181
# @@protoc_insertion_point(module_scope)
